(function ($) {
	'use strict';

	$(document).ready(function ($) {

		/* ========================================================================
		 * Variables
		 * ======================================================================== */

		var body = $('body'),
			menuToggle = $('.menu-toggle'),
			parentMenuItem = $('.menu-item-has-children > a'),
			currencySVG = $('.currency-row .icon'),
			postsScroller = $('.posts-scroller'),
			searchTrigger = $('.search-trigger'),
			search = $('.search-wrap'),
			tabNav = $('.tab-nav a'),
			tab = $('.tab'),
			qa_q = $('.q-wrap'),
			qa_a = $('.a-wrap'),
			start = $('.start-section'),
			numbers = $('.numbers-section'),
			countTo = $('.count-to'),
			whyMobileSlider = $('.why-section .items-wrap'),
			MobileSlider = $('.news-section .posts-wrap'),
			toggleCats = $('.toggle-cats'),
			locationsMobileSlider = $('.city-wrap .row'),
			timeline = $('.timeline-wrap .row-wrap'),
			citySelect = $('.city-select'),
			atmSelect = $('.atm-select'),
			gallery = $('.gallery'),
			linkToMarker = $('.link-to-location'),
			atmMap = $('.locations-wrap');

		/* ========================================================================
		 * Menu Toggle
		 * ======================================================================== */

		menuToggle.on('click', function () {
			body.toggleClass('show-menu');

			body.removeClass('show-search');
		});

		/* ========================================================================
		 * Mobile Menu
		 * ======================================================================== */

		if ($(window).width() < 1200) {
			parentMenuItem.on('click', function () {
				var menuItem = $(this).parent();

				if (menuItem.hasClass('show-sub-menu')) {
					menuItem.removeClass('show-sub-menu');
					menuItem.find(' > .sub-menu').slideUp(300);
				} else {
					menuItem.addClass('show-sub-menu');
					menuItem.find(' > .sub-menu').slideDown(300);
				}
			});
		}

		/* ========================================================================
		 * Sticky Nav
		 * ======================================================================== */

		function sticky() {
			if ($(window).scrollTop() > 0) {
				body.addClass('sticky-nav');
			} else {
				body.removeClass('sticky-nav');
			}
		}

		if ($(window).width() < 1200) {
			$(window).on('scroll load', function () {
				sticky();
			});
		}

		/* ========================================================================
		 * Search Toggle
		 * ======================================================================== */

		searchTrigger.on('click', function (e) {
			e.stopPropagation();
			body.toggleClass('show-search');
		});

		search.on('click', function (e) {
			e.stopPropagation();
		});

		$(document).on('click', function () {
			body.removeClass('show-search');
		});

		/* ========================================================================
		 * SVG IMG to CODE
		 * ======================================================================== */

		currencySVG.each(function () {
			var $this = $(this),
				color = $this.data('color');

			$this.find('path').css('fill', color);
		});

		/* ========================================================================
		 * Posts Scroller
		 * ======================================================================== */

		postsScroller.slick({
			autoplay: true,
			autoplaySpeed: 3000,
			slidesToShow: 1,
			slidesToScroll: 1,
			arrows: false,
		});

		/* ========================================================================
		 * Why Mobile Slider
		 * ======================================================================== */

		if ($(window).width() < 768) {
			whyMobileSlider.slick({
				autoplay: true,
				autoplaySpeed: 4000,
				speed: 700,
				slidesToShow: 1,
				slidesToScroll: 1,
				arrows: false,
				variableWidth: true,
				centerMode: true
			});
		}

		if ($(window).width() < 768) {
			MobileSlider.slick({
				slidesToShow: 1,
				slidesToScroll: 1,
				arrows: false,
				variableWidth: true,
				centerMode: true
			});
		}

		/* ========================================================================
		 * Tab
		 * ======================================================================== */

		tabNav.on('click', function (e) {
			e.preventDefault();

			var $this = $(this),
				tabTarget = $this.attr('href');

			if (!$this.parent().hasClass('active')) {
				tabNav.parent().removeClass('active');
				$this.parent().addClass('active');

				tab.find('.tab-inner-wrap').removeClass('fade-in');
				setTimeout(function () {
					tab.removeClass('first-active');
					tab.removeClass('active');
					$(tabTarget).addClass('active');
				}, 200);

				setTimeout(function () {
					$(tabTarget).find('.tab-inner-wrap').addClass('fade-in');
				}, 300);
			}
		});

		/* ========================================================================
		 * Accordion
		 * ======================================================================== */

		qa_q.on('click', function (e) {
			var $this = $(this);

			if ($this.hasClass('open')) {
				qa_a.slideUp(300);
				$this.removeClass('open');
			} else {
				qa_a.slideUp(300);
				qa_q.removeClass('open');
				$this.addClass('open');
				$this.next().slideDown(300);
			}
		});

		if ($(window).width() < 992) {
			$('.tab-inner-wrap > h3').on('click', function (e) {
				var $this = $(this);

				if ($this.hasClass('open')) {
					$this.next().slideUp(300);
					$this.removeClass('open');
				} else {
					$('.qa-main-wrap').slideUp(300);
					$('.tab-inner-wrap > h3').removeClass('open');
					$this.addClass('open');
					$this.next().slideDown(300);
				}
			});
		}

		/* ========================================================================
		 * Animations
		 * ======================================================================== */

		$(window).on('scroll load', function () {

			if (start.length > 0 && !start.hasClass('start-anim')) {

				if (($(window).scrollTop() + $(window).height() / 2) > start.offset().top) {
					start.addClass('start-anim')
				}
			}

			if (numbers.length > 0 && !numbers.hasClass('start-anim')) {

				if (($(window).scrollTop() + $(window).height() / 2) > numbers.offset().top) {
					numbers.addClass('start-anim');
					countTo.countTo({
						formatter: function (value, options) {
							value = value.toFixed(options.decimals);
							value = value.replace(/\B(?=(\d{3})+(?!\d))/g, '.');
							return value;
						}
					});
				}
			}

			if (timeline.length > 0) {
				timeline.each(function () {
					var $this = $(this);
					if (!$this.hasClass('start-anim')) {
						if (($(window).scrollTop() + $(window).height()) > $this.offset().top) {
							$this.addClass('start-anim');
						}
					}
				});
			}
		});

		/* ========================================================================
		 * Toggle Cats
		 * ======================================================================== */

		toggleCats.on('click', function (e) {
			e.preventDefault();
			body.toggleClass('show-cats');
		});

		/* ========================================================================
		 * Dropdown Menu
		 * ======================================================================== */

		$('.dropdown-wrap').each(function () {
			var $this = $(this);

			$this.find('button').on('click', function (e) {
				e.stopPropagation();

				if ($this.hasClass('open')) {
					$('.dropdown-wrap').removeClass('open');
				} else {
					$('.dropdown-wrap').removeClass('open');
					$this.addClass('open');
				}
			});

			$this.find('.dropdown-menu').on('click', function (e) {
				e.stopPropagation();
			});

			$('html, body').on('click', function (e) {
				$('.dropdown-wrap').removeClass('open');
			});

			$this.find('.dropdown-menu').find('span').on('click', function (e) {
				e.preventDefault();
				var item = $(this),
					value = $(this).text();
				$this.find('.dropdown-menu').parent().find('button span').html(value);
				$this.removeClass('open');
			});
		});

		citySelect.find('.dropdown-menu').find('span').on('click', function (e) {
			var dataVal = $(this).data('value');
			filterMarkers(dataVal, atmSelect.data('selected'));
			citySelect.data('selected', dataVal);
		});

		atmSelect.find('.dropdown-menu').find('span').on('click', function (e) {
			var dataVal = $(this).data('value');
			filterMarkers(citySelect.data('selected'), dataVal);
			atmSelect.data('selected', dataVal);
		});

		/* ========================================================================
		 * Locations Mobile Slider
		 * ======================================================================== */

		if ($(window).width() < 481) {
			locationsMobileSlider.slick({
				slidesToShow: 1,
				slidesToScroll: 1,
				arrows: false,
				variableWidth: true,
			});
		}

		/* ========================================================================
		 * Gallery Slider
		 * ======================================================================== */

		gallery.slick({
			slidesToShow: 3,
			slidesToScroll: 1,
			arrows: true,
			prevArrow: '<button class="slick-prev"><i class="fas fa-chevron-left"></i></button>',
			nextArrow: '<button class="slick-next"><i class="fas fa-chevron-right"></i></button>',
			responsive: [{
					breakpoint: 992,
					settings: {
						slidesToShow: 2
					}
				},
				{
					breakpoint: 480,
					settings: {
						slidesToShow: 1
					}
				}
			]
		});

		/* ========================================================================
		 * Jump to Marker
		 * ======================================================================== */

		linkToMarker.on('click', function () {
			var lat = $(this).data('lat'),
				lng = $(this).data('lng'),
				atmMapTop = atmMap.offset().top - 50;

			centerMarker(lat, lng);

			$('html, body').animate({
				scrollTop: atmMapTop
			}, 300);
		});


	}); // End Document Ready

}(jQuery));
