/* ========================================================================
 * Hash & Go Map
 * ======================================================================== */
var mapStyles = [{
	featureType: "administrative",
	elementType: "labels.text.fill",
	stylers: [{
		color: "#444444"
	}]
}, {
	featureType: "landscape",
	elementType: "all",
	stylers: [{
		color: "#f2f2f2"
	}]
}, {
	featureType: "poi",
	elementType: "all",
	stylers: [{
		visibility: "off"
	}]
}, {
	featureType: "road",
	elementType: "all",
	stylers: [{
		saturation: -100
	}, {
		lightness: 45
	}]
}, {
	featureType: "road.highway",
	elementType: "all",
	stylers: [{
		visibility: "simplified"
	}]
}, {
	featureType: "road.highway",
	elementType: "geometry.fill",
	stylers: [{
		saturation: "-21"
	}, {
		gamma: "2.98"
	}, {
		weight: "4.77"
	}, {
		lightness: "20"
	}]
}, {
	featureType: "road.arterial",
	elementType: "labels.icon",
	stylers: [{
		visibility: "off"
	}]
}, {
	featureType: "transit",
	elementType: "all",
	stylers: [{
		visibility: "off"
	}]
}, {
	featureType: "water",
	elementType: "all",
	stylers: [{
		color: "#2a4e6e"
	}, {
		visibility: "on"
	}]
}];

if (jQuery('#hashgomap').length > 0) {
	var gmarkers1 = [];
	var markers1 = [];
	var infowindow = new google.maps.InfoWindow({
		content: ''
	});
	var markerCluster;

	// Our markers
	jQuery('.map-wrap .marker').each(function (i) {
		var $this = jQuery(this);
		var location = [i + 1, $this.find('h5').text(), $this.data('lat'), $this.data('lng'), $this.data('cat'), $this.html()];
		markers1.push(location);
	});

	/**
	 * Function to init map
	 */

	function initialize() {
		var center = new google.maps.LatLng(markers1[0][2], markers1[0][3]);
		var mapOptions = {
			zoom: 7.5,
			center: center,
			scrollwheel: true,
			mapTypeControl: false,
			fullscreenControl: false,
			styles: mapStyles
		};

		map = new google.maps.Map(document.getElementById('hashgomap'), mapOptions);
		for (i = 0; i < markers1.length; i++) {
			addMarker(markers1[i]);
		}

		markerCluster = new MarkerClusterer(map, gmarkers1, {
			imagePath: js_vars.url + '/assets/images/cluster'
		});

		map.fitBounds(bounds);
	}

	/**
	 * Function to add marker to map
	 */

	var bounds = new google.maps.LatLngBounds();

	function addMarker(marker) {
		var category = marker[4];
		var title = marker[1];
		var pos = new google.maps.LatLng(marker[2], marker[3]);
		var content = marker[5];

		marker1 = new google.maps.Marker({
			title: title,
			position: pos,
			category: category,
			map: map,
			icon: js_vars.url + '/assets/images/hash_go-logo.png'
		});

		gmarkers1.push(marker1);
		bounds.extend(pos);

		// Marker click listener
		google.maps.event.addListener(marker1, 'click', (function (marker1, content) {
			return function () {
				console.log('Gmarker 1 gets pushed');
				infowindow.setContent(content);
				infowindow.open(map, marker1);
				map.panTo(this.getPosition());
			}
		})(marker1, content));
	}

	/**
	 * Function to filter markers by category
	 */

	filterMarkers = function (category) {
		var newmarkers = [];
		for (i = 0; i < markers1.length; i++) {
			marker = gmarkers1[i];
			// If is same category or category not picked
			if (marker.category == category || category.length === 0) {
				marker.setVisible(true);
				newmarkers.push(marker);
			}
			// Categories don't match 
			else {
				marker.setVisible(false);
			}
		}
		markerCluster.clearMarkers();
		markerCluster.addMarkers(newmarkers);
		infowindow.close();
		map.fitBounds(bounds);
	}

	// Init map
	initialize();
}


/* ========================================================================
 * ATM Map
 * ======================================================================== */

if (jQuery('#atmmap').length > 0) {
	var gmarkers1 = [];
	var markers1 = [];
	var infowindow = new google.maps.InfoWindow({
		content: ''
	});
	var markerCluster;

	// Our markers
	jQuery('.map-wrap .marker').each(function (i) {
		var $this = jQuery(this);
		var location = [i + 1, $this.find('h5').text(), $this.data('lat'), $this.data('lng'), $this.data('cat'), $this.data('type'), $this.html()];
		markers1.push(location);
	});

	/**
	 * Function to init map
	 */

	function initialize() {
		var center = new google.maps.LatLng(markers1[0][2], markers1[0][3]);
		var mapOptions = {
			zoom: 7.5,
			center: center,
			scrollwheel: true,
			mapTypeControl: false,
			fullscreenControl: false,
			styles: mapStyles
		};

		map = new google.maps.Map(document.getElementById('atmmap'), mapOptions);
		for (i = 0; i < markers1.length; i++) {
			addMarker(markers1[i]);
		}

		markerCluster = new MarkerClusterer(map, gmarkers1, {
			imagePath: js_vars.url + '/assets/images/cluster'
		});

		map.fitBounds(bounds);
	}

	/**
	 * Function to add marker to map
	 */

	var bounds = new google.maps.LatLngBounds();

	function addMarker(marker) {
		var city = marker[4];
		var type = marker[5];
		var title = marker[1];
		var pos = new google.maps.LatLng(marker[2], marker[3]);
		var content = marker[6];

		marker1 = new google.maps.Marker({
			title: title,
			position: pos,
			city: city,
			type: type,
			map: map,
			icon: js_vars.url + '/assets/images/atm.png'
		});

		gmarkers1.push(marker1);
		bounds.extend(pos);

		// Marker click listener
		google.maps.event.addListener(marker1, 'click', (function (marker1, content) {
			return function () {
				console.log('Gmarker 1 gets pushed');
				infowindow.setContent(content);
				infowindow.open(map, marker1);
				map.panTo(this.getPosition());
			}
		})(marker1, content));
	}

	/**
	 * Function to filter markers by category
	 */

	filterMarkers = function (city, type) {
		var newmarkers = [];

		for (i = 0; i < markers1.length; i++) {
			marker = gmarkers1[i];
			// If is same category or category not picked
			if ((marker.city == city || city.length === 0) && (marker.type == type || type.length === 0)) {
				marker.setVisible(true);
				newmarkers.push(marker);
			}
			// Categories don't match 
			else {
				marker.setVisible(false);
			}
		}
		markerCluster.clearMarkers();
		markerCluster.addMarkers(newmarkers);
		infowindow.close();
		map.fitBounds(bounds);
	}

	centerMarker = function (lat, lng) {
        var latlng = new google.maps.LatLng(lat, lng);

		console.log(lat + ' ' + lng);
        map.setCenter(latlng); 
        map.setZoom(10);
	}

	// Init map
	initialize();
}
