<?php
/**
 * Customizer settings.
 *
 * @package ECD
 */

/**
 * Register additional scripts.
 */
function ecd_customize_additional_scripts( $wp_customize ) {

	// Register a setting.
	$wp_customize->add_setting(
		'ecd_header_scripts',
		array(
			'default'           => '',
			'sanitize_callback' => 'force_balance_tags',
		)
	);

	// Create the setting field.
	$wp_customize->add_control(
		'ecd_header_scripts',
		array(
			'label'       => esc_html__( 'Header Scripts', 'ecd' ),
			'description' => esc_html__( 'Additional scripts to add to the header. Basic HTML tags are allowed.', 'ecd' ),
			'section'     => 'ecd_additional_scripts_section',
			'type'        => 'textarea',
		)
	);

	// Register a setting.
	$wp_customize->add_setting(
		'ecd_footer_scripts',
		array(
			'default'           => '',
			'sanitize_callback' => 'force_balance_tags',
		)
	);

	// Create the setting field.
	$wp_customize->add_control(
		'ecd_footer_scripts',
		array(
			'label'       => esc_html__( 'Footer Scripts', 'ecd' ),
			'description' => esc_html__( 'Additional scripts to add to the footer. Basic HTML tags are allowed.', 'ecd' ),
			'section'     => 'ecd_additional_scripts_section',
			'type'        => 'textarea',
		)
	);
}
add_action( 'customize_register', 'ecd_customize_additional_scripts' );

/**
 * Register a social icons setting.
 */
function ecd_customize_social_icons( $wp_customize ) {

	// Create an array of our social links for ease of setup.
	$social_networks = array( 'ecdebook', 'googleplus', 'instagram', 'linkedin', 'twitter' );

	// Loop through our networks to setup our fields.
	foreach ( $social_networks as $network ) {

		// Register a setting.
		$wp_customize->add_setting(
			'ecd_' . $network . '_link',
			array(
				'default' => '',
				'sanitize_callback' => 'esc_url',
			)
		);

		// Create the setting field.
		$wp_customize->add_control(
			'ecd_' . $network . '_link',
			array(
				'label'   => /* translators: the social network name. */ sprintf( esc_html__( '%s Link', 'ecd' ), ucwords( $network ) ),
				'section' => 'ecd_social_links_section',
				'type'    => 'text',
			)
		);
	}
}
add_action( 'customize_register', 'ecd_customize_social_icons' );

/**
 * Register copyright text setting.
 */
function ecd_customize_copyright_text( $wp_customize ) {

	// Register a setting.
	$wp_customize->add_setting(
		'ecd_copyright_text',
		array(
			'default' => '',
		)
	);

	// Create the setting field.
	$wp_customize->add_control(
		new Text_Editor_Custom_Control(
			$wp_customize,
			'ecd_copyright_text',
			array(
				'label'       => esc_html__( 'Copyright Text', 'ecd' ),
				'description' => esc_html__( 'The copyright text will be displayed in the footer. Basic HTML tags allowed.', 'ecd' ),
				'section'     => 'ecd_footer_section',
				'type'        => 'textarea',
			)
		)
	);
}
add_action( 'customize_register', 'ecd_customize_copyright_text' );
