<?php

/**
 * Custom scripts and styles.
 *
 * @package Rutgers
 */

/**
 * Register Google font.
 *
 * @link http://themeshaper.com/2014/08/13/how-to-add-google-fonts-to-wordpress-themes/
 */
function ecd_font_url()
{

    $fonts_url = '';

    /**
     * Translators: If there are characters in your language that are not
     * supported by the folloecdg, translate this to 'off'. Do not translate
     * into your own language.
     */
    $roboto = esc_html_x('on', 'Roboto font: on or off', 'ecd');
    $open_sans = esc_html_x('on', 'Open Sans font: on or off', 'ecd');

    if ('off' !== $roboto || 'off' !== $open_sans) {
        $font_families = array();

        if ('off' !== $roboto) {
            $font_families[] = 'Roboto:400,700';
        }

        if ('off' !== $open_sans) {
            $font_families[] = 'Open Sans:400,300,700';
        }

        $query_args = array(
            'family' => urlencode(implode('|', $font_families)),
        );

        $fonts_url = add_query_arg($query_args, '//fonts.googleapis.com/css');
    }

    return $fonts_url;
}

/**
 * Enqueue scripts and styles.
 */
function ecd_scripts()
{
    /**
     * If WP is in script debug, or we pass ?script_debug in a URL - set debug to true.
     */
    $debug = (defined('SCRIPT_DEBUG') && SCRIPT_DEBUG == true) || (isset($_GET['script_debug'])) ? true : false;

    /**
     * If we are debugging the site, use a unique version every page load so as to ensure no cache issues.
     */
    $version = '1.0.' . rand();

    /**
     * Should we load minified files?
     */
    $suffix = (true === $debug) ? '' : '.min';

    // Register styles.
    wp_register_style('ecd-google-font', ecd_font_url(), array(), null);

    // Enqueue styles.
    wp_enqueue_style('ecd-google-font');
    wp_enqueue_style('ecd-style', get_stylesheet_directory_uri() . '/style' . $suffix . '.css', array(), $version);

    wp_enqueue_script('ecd-scripts', get_template_directory_uri() . '/assets/scripts/project' . $suffix . '.js', array('jquery'), $version, true);


    if (is_page_template('templates/hash-go.php') || is_page_template('templates/crypto-atm.php')) :
        wp_enqueue_script('map-init',  get_template_directory_uri() . '/assets/scripts/map.js', true, true, true);
        wp_enqueue_script('google-maps-api-markers', 'https://unpkg.com/@google/markerclustererplus@4.0.1/dist/markerclustererplus.min.js', false, false, false);
        wp_enqueue_script('google-maps-api', 'https://maps.googleapis.com/maps/api/js?key=AIzaSyC5SSyVy0eAzj-T-XNQFlLarAsedYCWdqI', false, false, false);
    endif;


    if (is_singular() && comments_open() && get_option('thread_comments')) {
        wp_enqueue_script('comment-reply');
    }

    // Enqueue the scaffolding Library script.
    if (is_page_template('template-scaffolding.php')) {
        wp_enqueue_script('ecd-scaffolding', get_template_directory_uri() . '/assets/scripts/scaffolding' . $suffix . '.js', array('jquery'), $version, true);
    }

    $js_vars = array(

        'url'                 =>     get_template_directory_uri(),
        'admin_url'           =>     admin_url('admin-ajax.php'),
        'site_url'            =>    home_url(),
        'nonce'               =>     wp_create_nonce('ajax-nonce')
    );

    // Localize php variables
    wp_localize_script('ecd-scripts', 'js_vars', $js_vars);
}
add_action('wp_enqueue_scripts', 'ecd_scripts');

/**
 * Custom Admin Styles
 */
add_action('admin_head', 'my_custom_fonts');

function my_custom_fonts()
{
    echo '<style>
    #edittag {
			max-width: 1200px;
		}
  </style>';
}

/**
 * Add SVG definitions to footer.
 */
function ecd_include_svg_icons()
{

    // Define SVG sprite file.
    $svg_icons = get_template_directory() . '/assets/images/svg-icons.svg';

    // If it exists, include it.
    if (file_exists($svg_icons)) {
        require_once($svg_icons);
    }
}
add_action('wp_footer', 'ecd_include_svg_icons', 9999);

add_filter('use_block_editor_for_post', '__return_false');
