<?php

/**
 * The main template file.
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package ECD
 */

get_header(); ?>

<div class="primary content-area">
    <main id="main" class="site-main">

        <section class="page-hero-section" style="background-image:url(<?php echo wp_get_attachment_image_url(get_field('page_hero_image', 'option'), 'full'); ?>)">
            <div class="container">
                <?php if (function_exists('yoast_breadcrumb')) {
                    yoast_breadcrumb('<p id="breadcrumbs">', '</p>');
                } ?>
                <h1><?php single_post_title(); ?></h1>

                <div class="page-hero-links">
                    <?php echo ecd_acf_link(get_field('login_link', 'option'), 'button white no-bg border'); ?>
                    <?php echo ecd_acf_link(get_field('register_link', 'option'), 'button orange'); ?>
                </div>
            </div>
        </section>

        <section class="posts-section">
            <div class="container">
                <div class="search-wrap">
                    <?php get_search_form(); ?>
                </div>
                
                <?php
                $cats = get_terms('category', array('hide_empty' => 'false')); ?>

                <?php if ($cats) : ?>
                    <a href="#" class="toggle-cats"><span><?php _e('Categories', 'ecd'); ?></span><i class="fas fa-chevron-right"></i></a>

                    <div class="cats-wrap">
                        <?php foreach ($cats as $cat) : ?>
                            <a class="cat-link" href="<?php echo get_term_link($cat->term_id); ?>" class="category"><span style="background-color:<?php echo get_field('color', 'category_' . $cat->term_id); ?>"></span><?php echo $cat->name; ?></a>
                        <?php endforeach; ?>
                    </div>
                <?php endif; ?>

                <?php
                $paged = (get_query_var('paged')) ? get_query_var('paged') : 1; 
                $args = array(
                    'post_type' => 'post',
                    'posts_per_page' => 10,
                    'paged' => $paged
                );
                $wp_query = new WP_Query( $args );
                ?>

                <?php if ($wp_query ->have_posts()) : ?>

                    <div class="posts-wrap">
                        <?php while ($wp_query ->have_posts()) : $wp_query ->the_post(); ?>

                            <?php get_template_part('template-parts/content', 'post'); ?>

                        <?php endwhile; ?>
                    </div>

                    <?php echo ecd_page_numbers_pagination(); ?>

                <?php else : ?>

                    <?php get_template_part('template-parts/content', 'none'); ?>

                <?php endif; ?>
            </div>
        </section>

    </main><!-- #main -->
</div><!-- .primary -->

<?php get_sidebar(); ?>

<?php get_footer(); ?>