<?php

/**
 * Template Name: Hash & Go
 */

$args = array('post_type'  =>  'merchant', 'posts_per_page' => -1);
$merchants = new WP_Query($args);

$cities = get_terms('merchant-city', array());

wp_reset_query();

get_header(); ?>

<div id="primary" class="content-area">
    <main id="main" class="site-main" role="main">
        <?php while (have_posts()) : the_post(); ?>

            <?php get_template_part('template-parts/page-hero'); ?>

            <section class="hash-go-section">
                <div class="container">
                    <div class="intro-text">
                        <div class="text">
                            <?php the_content(); ?>
                        </div>

                        <div class="image-wrap"><?php echo wp_get_attachment_image(get_field('image'), 'full'); ?></div>
                    </div>

                    <div class="locations-wrap">
                        <h3><?php the_field('title'); ?></h3>

                        <div class="action-bar">
                            <div class="dropdown-wrap city-select" data-selected="">
                                <button class="dropdown-button"><span><?php _e('City', 'ecd'); ?></span></button>
                                <ul class="dropdown-menu">
                                    <li><span data-value=""><?php _e('All Cities', 'ecd'); ?></span></li>
                                    <?php foreach ($cities as $city) : ?>
                                        <li><span data-value="<?php echo $city->name; ?>"><?php echo $city->name; ?></span></li>
                                    <?php endforeach; ?>
                                </ul>
                            </div>

                            <?php echo ecd_acf_link(get_field('partners_link'), 'simple-link', '<i class="fas fa-chevron-right"></i>'); ?>
                        </div>

                        <div class="hash-map">
                            <div class="map-wrap" id="hashgomap">
                                <?php while ($merchants->have_posts()) : $merchants->the_post(); ?>
                                    <?php
                                    $address = get_field('address');
                                    $latitude = get_field('latitude');
                                    $longitudes = get_field('longitudes');
                                    $status = get_field('status');
                                    $cryptocurrencies = get_field('cryptocurrencies');
                                    $city = get_the_terms(get_the_ID(), 'merchant-city')[0]->name;
                                    ?>
                                    <div class="marker" data-lat="<?php echo $latitude; ?>" data-lng="<?php echo $longitudes; ?>" data-cat="<?php echo $city; ?>">
                                        <div class="info-window">
                                            <h4 class="<?php echo ($status) ? 'active' : 'not-active'; ?>"><?php the_title(); ?></h4>
                                            <h5><?php echo $address; ?></h5>
                                            <p class="notice <?php echo ($status) ? 'green' : 'red'; ?>"><?php _e('Cryptocurrency payment service is working', 'ecd'); ?></p>
                                            <p><?php _e('CryptoCurrencies', 'ecd'); ?>: <strong><?php echo $cryptocurrencies; ?></strong></p>
                                        </div>
                                    </div>
                                <?php endwhile; ?>
                                <?php wp_reset_query(); ?>
                            </div>
                        </div>
                    </div>

                    <div class="partners-wrap" id="partners">

                        <?php foreach ($cities as $city) : ?>
                            <?php $class = ($city->count == 1) ? 'one' : ''; ?>
                            <div class="city-wrap <?php echo $class; ?>">
                                <h4><?php echo $city->name; ?></h4>
                                <div class="row">
                                    <?php
                                    $args = array(
                                        'post_type'         =>  'merchant',
                                        'posts_per_page'    =>  -1,
                                        'tax_query'         =>  array(
                                            'relation'  =>  'AND',
                                            array(
                                                'taxonomy' => 'merchant-city',
                                                'field'    => 'slug',
                                                'terms'    => $city->slug,
                                                'compare'  => '='
                                            )
                                        )
                                    );
                                    $merchants = new WP_Query($args);
                                    ?>
                                    <?php while ($merchants->have_posts()) : $merchants->the_post(); ?>
                                        <?php
                                        $address = get_field('address');
                                        $latitude = get_field('latitude');
                                        $longitudes = get_field('longitudes');
                                        $status = get_field('status');
                                        $cryptocurrencies = get_field('cryptocurrencies');
                                        $website_url = get_field('website_url');
                                        $city = get_the_terms(get_the_ID(), 'merchant-city')[0]->name;
                                        ?>
                                        <div class="partner-wrap">
                                            <div class="inner-wrap">
                                                <?php if ($website_url) : ?>
                                                    <a href="<?php echo $website_url; ?>" class="image" style="background-image:url(<?php echo get_the_post_thumbnail_url(get_the_ID(), 'full'); ?>);" target="_blank"></a>
                                                <?php else : ?>
                                                    <div class="image" style="background-image:url(<?php echo get_the_post_thumbnail_url(get_the_ID(), 'full'); ?>);"></div>
                                                <?php endif; ?>

                                                <?php if ($website_url) : ?>
                                                    <h5><a href="<?php echo $website_url; ?>" target="_blank"><?php the_title(); ?></a></h5>
                                                <?php else : ?>
                                                    <h5><?php the_title(); ?></h5>
                                                <?php endif; ?>

                                                <p><?php echo $address; ?></p>
                                                <p><?php _e('CryptoCurrency', 'ecd'); ?>: <?php echo $cryptocurrencies; ?></p>
                                            </div>
                                        </div>
                                    <?php endwhile; ?>
                                </div>
                            </div>
                        <?php endforeach; ?>

                    </div>
                </div>
            </section>

        <?php endwhile; ?>
    </main><!-- #main -->
</div><!-- #primary -->

<?php
get_footer();
